@@ -8,6 +8,12 @@ __all__ = (
     "__license__",
 )
 
+__requirements__ = {
+    'all': [
+        "setuptools",
+        "importlib-metadata"
+    ]
+}
 
 import importlib_metadata
 
@@ -19,4 +25,5 @@ __summary__ = metadata["summary"]
 __version__ = metadata["version"]
 __author__ = metadata["author"]
 __email__ = metadata["author-email"]
-__license__ = metadata["license"]
\ No newline at end of file
+__license__ = metadata["license"]
+__requirements__ = metadata["requirements"]
\ No newline at end of file
